@@ -3,19 +3,20 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -112,7 +113,12 @@ typedef	enum
 	eDSInvalidContinueData		=	-14078,
 	eDSInvalidBuffFormat		=	-14079,
 	eDSInvalidPatternMatchType	=	-14080,
-	eDSRefTableError			=	-14081,
+	eDSRefTableError					=	-14081,
+	eDSRefTableNilError					=	-14082,
+	eDSRefTableIndexOutOfBoundsError	=	-14083,
+	eDSRefTableEntryNilError			=	-14084,
+	eDSRefTableCSBPAllocError			=	-14085,
+	eDSRefTableFWAllocError				=	-14086,
 
 	eDSAuthFailed				=	-14090,
 	eDSAuthMethodNotSupported	=	-14091,
@@ -163,6 +169,9 @@ typedef	enum
 	eDSAuthPasswordTooLong		=	-14171,
 	eDSAuthPasswordNeedsLetter	=	-14172,
 	eDSAuthPasswordNeedsDigit	=	-14173,
+	eDSAuthPasswordChangeTooSoon=	-14174,
+	eDSAuthInvalidLogonHours	= 	-14175,
+	eDSAuthInvalidComputer		= 	-14176,
 	
 	eDSNullParameter			=	-14200,
 	eDSNullDataBuff				=	-14201,
