@@ -37,6 +37,7 @@
 #include <limits.h>		// for PATH_MAX
 #include <stdio.h>		// for PATH_MAX, FILE, fopen(), etc.
 #include <fstream>	// for classes fstream and ios
+#include <sys/stat.h>			// for fstat(), stat() and structs
 
 using namespace std;
 
@@ -90,7 +91,8 @@ public:
 	virtual	sInt64	tellp		( void )	throw( OSErr );
 
 	virtual	sInt64	FileSize	( void )	throw( OSErr );
-
+	virtual void	ModDate		( struct timespec *outModTime );
+	
 protected:
 	DSMutexSemaphore	fLock;
 	char		   *fFilePath;
@@ -102,6 +104,7 @@ protected:
 	sInt64			fWritePos;
 	bool			fReadPosOK;
 	bool			fWritePosOK;
+	struct stat		fStatStruct;
 };
 
 inline CFile& CFile::flush ( void ) throw( OSErr )
